==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/zu-ZA/mail.php <==
<?php

return [
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'a_user_canceled' => 'Umsebenzisi ukhanse isicelo sezinto kuwebhusayithi',
    'a_user_requested' => 'Umsebenzisi ucele into ku-website',
    'accessory_name' => 'Igama lokufinyelela:',
    'additional_notes' => 'Amanothi angeziwe:',
    'admin_has_created' => 'Umlawuli udale i-akhawunti kuwe: iwebhusayithi yewebhu.',
    'asset' => 'Impahla:',
    'asset_name' => 'Igama lomhlaba:',
    'asset_requested' => 'Ifa liceliwe',
    'asset_tag' => 'Ithegi lefa',
    'assigned_to' => 'Kwabiwa Ku',
    'best_regards' => 'Ozithobayo,',
    'canceled' => 'Ikhanseliwe:',
    'checkin_date' => 'Usuku lokuhlola:',
    'checkout_date' => 'Usuku lokuhlola:',
    'click_to_confirm' => 'Sicela uchofoze kusixhumanisi esilandelayo ukuqinisekisa i-akhawunti yakho yewebhu:',
    'click_on_the_link_accessory' => 'Sicela uchofoze kusixhumanisi ngezansi ukuze uqinisekise ukuthi uthole i-accessory.',
    'click_on_the_link_asset' => 'Sicela uchofoze kusixhumanisi ngezansi ukuze uqinisekise ukuthi uthole ifa.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'I-QTY yamanje',
    'Days' => 'Izinsuku',
    'days' => 'Izinsuku',
    'expecting_checkin_date' => 'Ilanga le-Checkin elilindelekile:',
    'expires' => 'Iphelelwa yisikhathi',
    'Expiring_Assets_Report' => 'Ukubika Okubanjelwe Amafa.',
    'Expiring_Licenses_Report' => 'Umbiko Welayisense Okuphelelwa yisikhathi.',
    'hello' => 'Sawubona',
    'hi' => 'Sawubona',
    'i_have_read' => 'Ngifunde futhi ngiyavumelana nemigomo yokusetshenziswa, futhi ngithole le nto.',
    'item' => 'Into:',
    'Item_Request_Canceled' => 'Into yokucela ikhanseliwe',
    'Item_Requested' => 'Into ifunwe',
    'link_to_update_password' => 'Sicela uchofoze kusixhumanisi esilandelayo ukuze ubuyekeze: iphasiwedi yakho yewebhu:',
    'login_first_admin' => 'Ngena ngemvume ekufakweni kwakho okusha kwe-Snipe-IT usebenzisa iziqinisekiso ezingezansi:',
    'login' => 'Ngena ngemvume:',
    'Low_Inventory_Report' => 'Umbiko Wokungenisa Okuphansi',
    'inventory_report' => 'Inventory Report',
    'min_QTY' => 'I-Min QTY',
    'name' => 'Igama',
    'new_item_checked' => 'Into entsha ihloliwe ngaphansi kwegama lakho, imininingwane ingezansi.',
    'password' => 'Iphasiwedi:',
    'password_reset' => 'I-Password Setha kabusha',

    'read_the_terms' => 'Sicela ufunde imigomo yokusetshenziswa ngezansi.',
    'read_the_terms_and_click' => 'Sicela ufunde imigomo yokusetshenziswa ngezansi, bese uchofoza isixhumanisi phansi ukuze uqinisekise ukuthi ufunda futhi uvumelana nemigomo yokusetshenziswa, futhi uthole ifa.',
    'requested' => 'Ucele:',
    'reset_link' => 'Iphasiwedi yakho Hlaziya kabusha Isixhumanisi',
    'reset_password' => 'Chofoza lapha ukuze usethe kabusha iphasiwedi yakho:',
    'serial' => 'Serial',
    'supplier' => 'Umphakeli',
    'tag' => 'Maka',
    'test_email' => 'I-imeyili yokuhlola evela ku-Snipe-IT',
    'test_mail_text' => 'Lokhu kuhlolwa kusuka ohlelweni lwezokuphathwa kwe-Asset ye-Snipe-IT. Uma unalokhu, i-imeyili isebenza :)',
    'the_following_item' => 'Into elandelayo ihloliwe ku:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'Ukuze usethe kabusha: iphasiwedi yewebhu, ugcwalise leli fomu:',
    'type' => 'Thayipha',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Umsebenzisi',
    'username' => 'Igama lomsebenzisi',
    'welcome' => 'Siyakwamukela: igama',
    'welcome_to' => 'Siyakwamukela ku: iwebhu!',
    'your_credentials' => 'Izimpawu zakho ze-Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
    'rights_reserved' => 'All rights reserved.',
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/zu-ZA/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'Izinsuku',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expiring_Assets_Report' => 'Ukubika Okubanjelwe Amafa.',
    'Expiring_Licenses_Report' => 'Umbiko Welayisense Okuphelelwa yisikhathi.',
    'Item_Request_Canceled' => 'Into yokucela ikhanseliwe',
    'Item_Requested' => 'Into ifunwe',
    'License_Checkin_Notification' => 'License checked in',
    'License_Checkout_Notification' => 'License checked out',
    'Low_Inventory_Report' => 'Umbiko Wokungenisa Okuphansi',
    'a_user_canceled' => 'Umsebenzisi ukhanse isicelo sezinto kuwebhusayithi',
    'a_user_requested' => 'Umsebenzisi ucele into ku-website',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'accessory_name' => 'Igama lokufinyelela:',
    'additional_notes' => 'Amanothi angeziwe:',
    'admin_has_created' => 'Umlawuli udale i-akhawunti kuwe: iwebhusayithi yewebhu.',
    'asset' => 'Impahla:',
    'asset_name' => 'Igama lomhlaba:',
    'asset_requested' => 'Ifa liceliwe',
    'asset_tag' => 'Ithegi lefa',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'Kwabiwa Ku',
    'best_regards' => 'Ozithobayo,',
    'canceled' => 'Ikhanseliwe:',
    'checkin_date' => 'Usuku lokuhlola:',
    'checkout_date' => 'Usuku lokuhlola:',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Sicela uchofoze kusixhumanisi ngezansi ukuze uqinisekise ukuthi uthole i-accessory.',
    'click_on_the_link_asset' => 'Sicela uchofoze kusixhumanisi ngezansi ukuze uqinisekise ukuthi uthole ifa.',
    'click_to_confirm' => 'Sicela uchofoze kusixhumanisi esilandelayo ukuqinisekisa i-akhawunti yakho yewebhu:',
    'current_QTY' => 'I-QTY yamanje',
    'days' => 'Izinsuku',
    'expecting_checkin_date' => 'Ilanga le-Checkin elilindelekile:',
    'expires' => 'Iphelelwa yisikhathi',
    'hello' => 'Sawubona',
    'hi' => 'Sawubona',
    'i_have_read' => 'Ngifunde futhi ngiyavumelana nemigomo yokusetshenziswa, futhi ngithole le nto.',
    'inventory_report' => 'Inventory Report',
    'item' => 'Into:',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'link_to_update_password' => 'Sicela uchofoze kusixhumanisi esilandelayo ukuze ubuyekeze: iphasiwedi yakho yewebhu:',
    'login' => 'Ngena ngemvume:',
    'login_first_admin' => 'Ngena ngemvume ekufakweni kwakho okusha kwe-Snipe-IT usebenzisa iziqinisekiso ezingezansi:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'min_QTY' => 'I-Min QTY',
    'name' => 'Igama',
    'new_item_checked' => 'Into entsha ihloliwe ngaphansi kwegama lakho, imininingwane ingezansi.',
    'notes' => 'Amanothi',
    'password' => 'Iphasiwedi:',
    'password_reset' => 'I-Password Setha kabusha',
    'read_the_terms' => 'Sicela ufunde imigomo yokusetshenziswa ngezansi.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'Ucele:',
    'reset_link' => 'Iphasiwedi yakho Hlaziya kabusha Isixhumanisi',
    'reset_password' => 'Chofoza lapha ukuze usethe kabusha iphasiwedi yakho:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'Serial',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Umphakeli',
    'tag' => 'Maka',
    'test_email' => 'I-imeyili yokuhlola evela ku-Snipe-IT',
    'test_mail_text' => 'Lokhu kuhlolwa kusuka ohlelweni lwezokuphathwa kwe-Asset ye-Snipe-IT. Uma unalokhu, i-imeyili isebenza :)',
    'the_following_item' => 'Into elandelayo ihloliwe ku:',
    'to_reset' => 'Ukuze usethe kabusha: iphasiwedi yewebhu, ugcwalise leli fomu:',
    'type' => 'Thayipha',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Umsebenzisi',
    'username' => 'Igama lomsebenzisi',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Siyakwamukela: igama',
    'welcome_to' => 'Siyakwamukela ku: iwebhu!',
    'your_assets' => 'View Your Assets',
    'your_credentials' => 'Izimpawu zakho ze-Snipe-IT',
    'mail_sent' => 'Mail sent successfully!',
];
